==> developer-center-api-2.4.6-20170727.041824-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/DomainConfigDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;

/**
 * Created by sty on 7/12/17.
 */
public class DomainConfigDto implements Serializable {

    private static final long serialVersionUID = 1L;

    //楼层域名
    private String homeDomain;
    //秒杀域名
    private String seckillDomain;
    //平台券域名
    private String goodsDomain;
    //活动域名
    private String activityDomain;
    //交易域名
    private String tradeDomain;
    //今日必抢域名
    private String todayrobDomain;
    //埋点系统域名
    private String embedDomain;
    //老手机端域名
    private String appDomain;

    public String getHomeDomain() {
        return homeDomain;
    }

    public void setHomeDomain(String homeDomain) {
        this.homeDomain = homeDomain;
    }

    public String getSeckillDomain() {
        return seckillDomain;
    }

    public void setSeckillDomain(String seckillDomain) {
        this.seckillDomain = seckillDomain;
    }

    public String getGoodsDomain() {
        return goodsDomain;
    }

    public void setGoodsDomain(String goodsDomain) {
        this.goodsDomain = goodsDomain;
    }

    public String getActivityDomain() {
        return activityDomain;
    }

    public void setActivityDomain(String activityDomain) {
        this.activityDomain = activityDomain;
    }

    public String getTradeDomain() {
        return tradeDomain;
    }

    public void setTradeDomain(String tradeDomain) {
        this.tradeDomain = tradeDomain;
    }

    public String getTodayrobDomain() {
        return todayrobDomain;
    }

    public void setTodayrobDomain(String todayrobDomain) {
        this.todayrobDomain = todayrobDomain;
    }

    public String getEmbedDomain() {
        return embedDomain;
    }

    public void setEmbedDomain(String embedDomain) {
        this.embedDomain = embedDomain;
    }

    public String getAppDomain() {
        return appDomain;
    }

    public void setAppDomain(String appDomain) {
        this.appDomain = appDomain;
    }
}

==> developer-center-api-3.5.59-sources.jar: cn/com/duiba/developer/center/api/domain/dto/DomainConfigDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;

/**
 * Created by sty on 7/12/17.
 */
public class DomainConfigDto implements Serializable {

    private static final long serialVersionUID = 1L;

    //楼层域名
    private String homeDomain;
    //秒杀域名
    private String seckillDomain;
    //平台券域名
    private String goodsDomain;
    //活动域名
    private String activityDomain;
    //交易域名
    private String tradeDomain;
    //今日必抢域名
    private String todayrobDomain;
    //埋点系统域名
    private String embedDomain;
    //老手机端域名
    private String appDomain;
    //推啊域名
    private String tuiaDomain;
    //cdn
    private String cdnDomain;

    public String getHomeDomain() {
        return homeDomain;
    }

    public void setHomeDomain(String homeDomain) {
        this.homeDomain = homeDomain;
    }

    public String getSeckillDomain() {
        return seckillDomain;
    }

    public void setSeckillDomain(String seckillDomain) {
        this.seckillDomain = seckillDomain;
    }

    public String getGoodsDomain() {
        return goodsDomain;
    }

    public void setGoodsDomain(String goodsDomain) {
        this.goodsDomain = goodsDomain;
    }

    public String getActivityDomain() {
        return activityDomain;
    }

    public void setActivityDomain(String activityDomain) {
        this.activityDomain = activityDomain;
    }

    public String getTradeDomain() {
        return tradeDomain;
    }

    public void setTradeDomain(String tradeDomain) {
        this.tradeDomain = tradeDomain;
    }

    public String getTodayrobDomain() {
        return todayrobDomain;
    }

    public void setTodayrobDomain(String todayrobDomain) {
        this.todayrobDomain = todayrobDomain;
    }

    public String getEmbedDomain() {
        return embedDomain;
    }

    public void setEmbedDomain(String embedDomain) {
        this.embedDomain = embedDomain;
    }

    public String getAppDomain() {
        return appDomain;
    }

    public void setAppDomain(String appDomain) {
        this.appDomain = appDomain;
    }

    public String getTuiaDomain() {
        return tuiaDomain;
    }

    public void setTuiaDomain(String tuiaDomain) {
        this.tuiaDomain = tuiaDomain;
    }

    public String getCdnDomain() {
        return cdnDomain;
    }

    public void setCdnDomain(String cdnDomain) {
        this.cdnDomain = cdnDomain;
    }
}
